Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3812)

Unified Diff: base/trace_event/process_memory_dump.h

Issue 1398163003: Handle EAGAIN error for the mincore syscall used (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@resident
Patch Set: Rebase. Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | base/trace_event/process_memory_dump.cc » ('j') | base/trace_event/process_memory_dump.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/trace_event/process_memory_dump.h
diff --git a/base/trace_event/process_memory_dump.h b/base/trace_event/process_memory_dump.h
index 4f7d141104dd3342a26c3263aa2686bf1f20eb5f..58209bc1dfcf7393c8b47247e3d81219b8d4800c 100644
--- a/base/trace_event/process_memory_dump.h
+++ b/base/trace_event/process_memory_dump.h
@@ -48,11 +48,15 @@ class BASE_EXPORT ProcessMemoryDump {
SmallMap<hash_map<std::string, MemoryAllocatorDump*>>;
#if defined(COUNT_RESIDENT_BYTES_SUPPORTED)
- // Returns the total bytes resident for a virtual address range, with given
- // |start_address| and |mapped_size|. |mapped_size| is specified in bytes. The
- // value returned is valid only if the given range is currently mmapped by the
- // process. The |start_address| must be page-aligned.
- static size_t CountResidentBytes(void* start_address, size_t mapped_size);
+ // Counts the total bytes resident for a virtual address range, with given
+ // |start_address| and |mapped_size| and sets |resident_size|. |mapped_size|
+ // is specified in bytes. The value returned is valid only if the given range
+ // is currently mmapped by the process. The |start_address| must be
+ // page-aligned.
+ // Returns true on success.
+ static bool CountResidentBytes(void* start_address,
+ size_t mapped_size,
+ size_t* resident_size);
#endif
ProcessMemoryDump(const scoped_refptr<MemoryDumpSessionState>& session_state);
« no previous file with comments | « no previous file | base/trace_event/process_memory_dump.cc » ('j') | base/trace_event/process_memory_dump.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698